@@ -1,3 +1,4 @@
+import os
 import logging
 import platform
 from pathlib import Path
@@ -10,6 +11,8 @@ def get_logger():
     console_log_level=logging.getLevelName(config.console_log_level)
     file_log_level=logging.getLevelName(config.file_log_level)
     log_dir=config.log_dir
+    if not os.path.exists(log_dir):
+        os.makedirs(log_dir)
     sys_name = platform.system()
     timestamp = datetime.now().strftime("%Y%m%d")
     if sys_name == "Windows":
